@@ -808,7 +808,7 @@ g_convert_with_fallback (const gchar *str,
 			 gssize       len,    
 			 const gchar *to_codeset,
 			 const gchar *from_codeset,
-			 gchar       *fallback,
+			 const gchar *fallback,
 			 gsize       *bytes_read,
 			 gsize       *bytes_written,
 			 GError     **error)
